==> kadu-0.3.9.tar.bz2: kadu/modules/default_sms/translations/default_sms_pl.ts <==
<!DOCTYPE TS><TS>
<context>
    <name>@default</name>
    <message>
        <source>Password</source>
        <translation>Hasło: </translation>
    </message>
    <message>
        <source>SMS Era Gateway</source>
        <translation>Bramka SMS Era GSM</translation>
    </message>
    <message>
        <source>User ID</source>
        <translation>ID Użytkownika: </translation>
    </message>
    <message>
        <source>Type of gateway</source>
        <translation>Rodzaj bramki</translation>
    </message>
</context>
<context>
    <name>SmsEraGateway</name>
    <message>
        <source>Provider gateway results page looks strange. SMS was probably NOT sent.</source>
        <translation>Bramka zwróciła dziwną odpowiedź. SMS prawdopodobnie nie został wysłany.</translation>
    </message>
    <message>
        <source>Error: </source>
        <translation>Błąd:</translation>
    </message>
    <message>
        <source>No error</source>
        <translation>Bez błędu</translation>
    </message>
    <message>
        <source>System failure</source>
        <translation>Awaria systemu</translation>
    </message>
    <message>
        <source>Unauthorised user</source>
        <translation>Użytkownik nieautoryzowany</translation>
    </message>
    <message>
        <source>Access forbidden</source>
        <translation>Dostęp zablokowany</translation>
    </message>
    <message>
        <source>Syntax error</source>
        <translation>Błąd składni</translation>
    </message>
    <message>
        <source>Limit of the sms run-down</source>
        <translation>Wyczerpany limit SMS</translation>
    </message>
    <message>
        <source>Wrong receiver adress</source>
        <translation>Błędny adres odbiorcy SMS</translation>
    </message>
    <message>
        <source>Message too long</source>
        <translation>Wiadomość za długa</translation>
    </message>
    <message>
        <source>Unknown error</source>
        <translation>Nieznany błąd</translation>
    </message>
</context>
<context>
    <name>SmsIdeaGateway</name>
    <message>
        <source>Provider gateway page looks strange. It&apos;s probably temporary disabled
or has beed changed too much to parse it correctly.</source>
        <translation>Wskazana bramka SMS jest niedostępna. Prawdopodobnie jest
czasowo wyłączona lub zmieniła zasady dostępu.</translation>
    </message>
    <message>
        <source>You exceeded your daily limit</source>
        <translation>Limit wysłanych SMS-ów został przekroczony.</translation>
    </message>
    <message>
        <source>Text from the picture is incorrect</source>
        <translation>Tekst z obrazka wpisany niepoprawnie.</translation>
    </message>
    <message>
        <source>The receiver has to enable SMS STANDARD service</source>
        <translation>Odbiorca wiadomości nie ma włączonej usługi SMS STANDARD.</translation>
    </message>
    <message>
        <source>Provider gateway results page looks strange. SMS was probably NOT sent.</source>
        <translation>Bramka zwróciła dziwną odpowiedź. SMS prawdopodobnie nie został wysłany.</translation>
    </message>
</context>
<context>
    <name>SmsPlusGateway</name>
    <message>
        <source>Provider gateway page looks strange. It&apos;s probably temporary disabled
or has beed changed too much to parse it correctly.</source>
        <translation>Wskazana bramka SMS jest niedostępna. Prawdopodobnie jest
czasowo wyłączona lub zmieniła zasady dostępu.</translation>
    </message>
    <message>
        <source>Provider gateway results page looks strange. SMS was probably NOT sent.</source>
        <translation>Bramka zwróciła dziwną odpowiedź. SMS prawdopodobnie nie został wysłany.</translation>
    </message>
</context>
</TS>

==> kadu-0.4.1.tar.bz2: kadu/modules/default_sms/translations/default_sms_pl.ts <==
<!DOCTYPE TS><TS>
<context>
    <name>@default</name>
    <message>
        <source>Password</source>
        <translation>Hasło: </translation>
    </message>
    <message>
        <source>SMS Era Gateway</source>
        <translation>Bramka SMS Era GSM</translation>
    </message>
    <message>
        <source>Type of gateway</source>
        <translation>Rodzaj bramki</translation>
    </message>
    <message>
        <source>User ID (48xxxxxxxxx)</source>
        <translation>ID użytkownika(48xxxxxxxxx)</translation>
    </message>
</context>
<context>
    <name>SmsEraGateway</name>
    <message>
        <source>Provider gateway results page looks strange. SMS was probably NOT sent.</source>
        <translation>Bramka zwróciła dziwną odpowiedź. SMS prawdopodobnie nie został wysłany.</translation>
    </message>
    <message>
        <source>Error: </source>
        <translation>Błąd:</translation>
    </message>
    <message>
        <source>No error</source>
        <translation>Bez błędu</translation>
    </message>
    <message>
        <source>System failure</source>
        <translation>Awaria systemu</translation>
    </message>
    <message>
        <source>Unauthorised user</source>
        <translation>Użytkownik nieautoryzowany</translation>
    </message>
    <message>
        <source>Access forbidden</source>
        <translation>Dostęp zablokowany</translation>
    </message>
    <message>
        <source>Syntax error</source>
        <translation>Błąd składni</translation>
    </message>
    <message>
        <source>Limit of the sms run-down</source>
        <translation>Wyczerpany limit SMS</translation>
    </message>
    <message>
        <source>Message too long</source>
        <translation>Wiadomość za długa</translation>
    </message>
    <message>
        <source>Wrong receiver address</source>
        <translation>Nieprawidłowy  adres odbiorcy</translation>
    </message>
    <message>
        <source>Unknown error (%1)</source>
        <translation>Nieznany błąd (%1)</translation>
    </message>
</context>
<context>
    <name>SmsIdeaGateway</name>
    <message>
        <source>Provider gateway page looks strange. It&apos;s probably temporary disabled
or has beed changed too much to parse it correctly.</source>
        <translation>Wskazana bramka SMS jest niedostępna. Prawdopodobnie jest
czasowo wyłączona lub zmieniła zasady dostępu.</translation>
    </message>
    <message>
        <source>You exceeded your daily limit</source>
        <translation>Limit wysłanych SMS-ów został przekroczony.</translation>
    </message>
    <message>
        <source>Text from the picture is incorrect</source>
        <translation>Tekst z obrazka wpisany niepoprawnie</translation>
    </message>
    <message>
        <source>The receiver has to enable SMS STANDARD service</source>
        <translation>Odbiorca wiadomości nie ma włączonej usługi SMS STANDARD.</translation>
    </message>
    <message>
        <source>Provider gateway results page looks strange. SMS was probably NOT sent.</source>
        <translation>Bramka zwróciła dziwną odpowiedź. SMS prawdopodobnie nie został wysłany.</translation>
    </message>
</context>
<context>
    <name>SmsPlusGateway</name>
    <message>
        <source>Provider gateway page looks strange. It&apos;s probably temporary disabled
or has beed changed too much to parse it correctly.</source>
        <translation>Wskazana bramka SMS jest niedostępna. Prawdopodobnie jest
czasowo wyłączona lub zmieniła zasady dostępu.</translation>
    </message>
    <message>
        <source>Provider gateway results page looks strange. SMS was probably NOT sent.</source>
        <translation>Bramka zwróciła dziwną odpowiedź. SMS prawdopodobnie nie został wysłany.</translation>
    </message>
    <message>
        <source>Limits have been exceeded, try again later.</source>
        <translation>Limit został przekroczony, spróbuj później.</translation>
    </message>
</context>
</TS>
